@@ -41,7 +41,7 @@ def cal_add_1(num1,num2):
 # ============================下面是模型的迭代选择===============================================================
 from sklearn.linear_model import RidgeClassifier,LogisticRegressionCV, Perceptron
 def LogisticRegressionCV_mdoel(X, Y, cv, score):
-    LogisticRegressionCV_auto = LogisticRegressionCV(random_state=0, n_jobs=-1)
+    LogisticRegressionCV_auto = LogisticRegressionCV(random_state=0, n_jobs=-1,max_iter=10000)
 
     # 搜索的参数是para
     param_dict = {"solver": ['newton-cg', 'lbfgs', 'liblinear', 'sag', 'saga'],
@@ -62,7 +62,7 @@ from sklearn.linear_model import SGDClassifier
 def SGDClassifier_model(X, Y, cv, score):
 
     # 首先实例化各个回归方法
-    SGDClassifier_auto = SGDClassifier(random_state=0,n_jobs=-1)
+    SGDClassifier_auto = SGDClassifier(random_state=0,n_jobs=-1,max_iter=10000)
     param_dict = {"penalty":['l2','elasticnet','l2'],  #
                   "loss":[ 'modified_huber', 'log'], #'hinge'
                   "class_weight":['none','balanced'],
@@ -98,7 +98,7 @@ from sklearn.svm import LinearSVC
 def LinearSVC_model(X, Y, cv, score):  # 这就是感知机
 
     # 首先实例化各个回归方法
-    LinearSVC_auto = LinearSVC(random_state=0)
+    LinearSVC_auto = LinearSVC(random_state=0,max_iter=10000)
     param_dict = {"penalty": ['l2', 'l1'],
                   "loss": ['hinge', 'squared_hinge'],
                   "dual": [True, False],
